CedarBackup3.actions.initialize — cedar-backup3 3.10.0 documentation

# CedarBackup3.actions.initialize

Implements the standard ‘initialize’ action. :author: Kenneth J. Pronovici <pronovic@ieee.org>

## Module Contents

CedarBackup3.actions.initialize.logger

CedarBackup3.actions.initialize.executeInitialize(configPath, options, config)

  Executes the initialize action.

  The initialize action initializes the media currently in the writer device so that Cedar Backup can recognize it later. This is an optional step; it’s only required if checkMedia is set on the store configuration.

  Parameters:

    - configPath (String representing a path on disk) – Path to configuration file on disk

    - options (Options object) – Program command-line options

    - config (Config object) – Program configuration